@@ -137,7 +137,7 @@ class Hist2D(object):
         th2f.SetTitle("%s;%s;%s" % (self.title, self.xlabel, self.ylabel))
         for ix in range(self.nbinsx):
             for iy in range(self.nbinsy):
-                th2f.SetBinContent(ix + 1, iy + 1, self.content[ix][iy])
+                th2f.SetBinContent(ix + 1, iy + 1, self.content[iy][ix])
         return th2f
 
 class Hist(object):
@@ -169,10 +169,11 @@ class Hist(object):
         self.xedges = [hist.GetBinLowEdge(i) for i in range(1, n + 2)]
         self.x      = [(self.xedges[i+1] + self.xedges[i])/2 for i in range(n)]
         self.xerr   = [(self.xedges[i+1] - self.xedges[i])/2 for i in range(n)]
+        self.xerr   = [self.xerr[:], self.xerr[:]]
         self.width  = [(self.xedges[i+1] - self.xedges[i])   for i in range(n)]
         self.y      = [hist.GetBinContent(i) for i in range(1, n + 1)]
         self.yerr   = [hist.GetBinError(  i) for i in range(1, n + 1)]
-        self.yerr   = [self.yerr, self.yerr]
+        self.yerr   = [self.yerr[:], self.yerr[:]]
         self.underflow = hist.GetBinContent(0)
         self.overflow  = hist.GetBinContent(self.nbins + 1)
     def __init_TGraph(self, hist):
@@ -185,10 +186,10 @@ class Hist(object):
             self.y.append(copy.copy(y))
         lower = [max(0, hist.GetErrorXlow(i))  for i in xrange(n)]
         upper = [max(0, hist.GetErrorXhigh(i)) for i in xrange(n)]
-        self.xerr = [lower, upper]
+        self.xerr = [lower[:], upper[:]]
         lower = [max(0, hist.GetErrorYlow(i))  for i in xrange(n)]
         upper = [max(0, hist.GetErrorYhigh(i)) for i in xrange(n)]
-        self.yerr = [lower, upper]
+        self.yerr = [lower[:], upper[:]]
         self.xedges = [self.x[i] - self.xerr[0][i] for i in xrange(n)]
         self.xedges.append(self.x[n - 1] + self.xerr[1][n - 1])
         self.width = [self.xedges[i + 1] - self.xedges[i] for i in range(n)]
@@ -216,6 +217,10 @@ class Hist(object):
             return min(vals)
         else:
             return threshold
+    def _av_yerr(self):
+        """Return average between the upper and lower xerr."""
+        return [(self.xerr[0][i] + self.xerr[1][i]) / 2
+                for i in range(self.nbins)]
     def _av_yerr(self):
         """Return average between the upper and lower yerr."""
         return [(self.yerr[0][i] + self.yerr[1][i]) / 2
@@ -261,7 +266,8 @@ class Hist(object):
         self.x.pop()
         self.width.pop()
         self.y.pop(index)
-        self.xerr.pop(index)
+        self.xerr[0].pop(index)
+        self.xerr[1].pop(index)
         self.yerr[0].pop(index)
         self.yerr[1].pop(index)
         if self.binlabels:
@@ -315,7 +321,7 @@ class Hist(object):
         """
         kwargs.pop('fmt', None)
         if xerr: kwargs['xerr'] = self.xerr
-        if yerr: kwargs['yerr'] = self._av_yerr()
+        if yerr: kwargs['yerr'] = self.yerr
         _load_pyplot()
         bar = plt.bar(self.xedges[0:-1], self.y, self.width, label=self.label,
                       **kwargs)
@@ -329,7 +335,7 @@ class Hist(object):
         All additional keyword arguments will be passed to pyplot.barh.
         """
         kwargs.pop('fmt', None)
-        if xerr: kwargs['xerr'] = self._av_yerr()
+        if xerr: kwargs['xerr'] = self.yerr
         if yerr: kwargs['yerr'] = self.xerr
         _load_pyplot()
         xcontent = [self.xedges[i] + self.width[i] * yoffset
@@ -373,13 +379,15 @@ class Hist(object):
         den_yerr = denominator._av_yerr()
         quotient.yerr = [0. for i in range(self.nbins)]
         for i in range(self.nbins):
-            if denominator[i] == 0:
+            if denominator[i] == 0 or self[i] == 0:
                 quotient.y[i] = 0.
             else:
                 quotient.y[i] = self[i] / denominator[i]
                 quotient.yerr[i] = quotient[i]
                 quotient.yerr[i] *= math.sqrt((num_yerr[i] / self[i]) ** 2 +
                                        (den_yerr[i] / denominator[i]) ** 2)
+            if quotient.yerr[i] > quotient[i]:
+                quotient.yerr[i] = quotient[i]
         quotient.yerr = [quotient.yerr, quotient.yerr]
         return quotient
     def divide_wilson(self, denominator):
