@@ -71,10 +71,15 @@ up by running 'cmsenv'."""
     elif os.path.exists(os.path.expanduser('~/.rootlogon.C')):
         ROOT.gROOT.Macro(os.path.expanduser('~/.rootlogon.C'))
 
+## Get terminal width
+import sys, fcntl, termios, struct
+data = fcntl.ioctl(sys.stdout.fileno(), termios.TIOCGWINSZ, '1234')
+ncolumns = struct.unpack('hh',data)[1]
+
 
 ######## Define styles #######################################################
 
-default_styles=r"""\
+default_styles=r"""
 import ROOT # allows access to ROOT colors (e.g. ROOT.kRed)
 
 
@@ -174,32 +179,35 @@ overflow_alpha = 0.5       # For matplotlib output
 #### Ratio plot
 ratio_fraction = 0.3  # Fraction of the canvas that bottom plot occupies
 ratio_cutoff = 10.    # Ignore bins this many times the average
+ratio_label = 'Ratio' # Label for the plot
 
 #### Define how much headroom to add to the plot
 top_padding_factor = 1.2
 top_padding_factor_log = 5.
 
 #### Plotting options based on histogram names
-####   ex: set "logy" : ["_pt"] to make plots with _pt in the name be logy
-options_by_histname = {"norm" : [""],   # area normalize
-                       "logx" : [""],
-                       "logy" : [""],
-                       "zero" : [""],
-                       "efficiency" : [""],
-                       "overflow" : [""],
-                       "underflow" : [""],
-                       "ratio" : [""]}
+## ex: set 'Logy' : ['_pt'] to make plots with _pt in the name be logy
+## These options are the same as the 'sticky' plotting options in the help menu
+
+options_by_histname = {'Norm' : [],   # area normalize
+                       'Logx' : [],
+                       'Logy' : [],
+                       'Zero' : [],
+                       'Eff' : [],
+                       'Overflow' : [],
+                       'Underflow' : [],
+                       'Ratio' : []}
 
 ##############################################################################
 ######## ROOT Output #########################################################
 
 #### Define the size of the legend in ROOT
-legend_width = 0.22        # Fraction of canvas width
-legend_entry_height = 0.04 # Fraction of canvas height
-max_legend_height = 0.3    # Fraction of canvas height
+legend_width = 0.38        # Fraction of canvas width
+legend_entry_height = 0.05 # Fraction of canvas height
+max_legend_height = 0.4    # Fraction of canvas height
 legend_left_bound = 0.20   # For left justification
-legend_right_bound = 0.87  # For right justification
-legend_upper_bound = 0.89  # For top justification
+legend_right_bound = 0.95  # For right justification
+legend_upper_bound = 0.91  # For top justification
 legend_lower_bound = 0.15  # For bottom justification
 legend_codes = { 1 : 'upper right',
                  2 : 'upper left',
@@ -344,13 +352,6 @@ def plotting_worker(queue, queue_globals, options):
                         options.output, options.ext)
         queue.task_done()
 
-#### This is where all the plotting actually happens
-def process_hist(path, name, counter, options):
-    if options.mpl:
-        process_hist_mpl(path, name, counter, options)
-    else:
-        process_hist_root(path, name, counter, options)
-
 #### This is where all the plotting actually happens
 def process_hist(path, name, counter, options):
     """Overlay all the instances of this plot."""
@@ -359,7 +360,10 @@ def process_hist(path, name, counter, options):
     hists = []
     #### Apply options to hist from each file
     for i, file in enumerate(files):
-        roothist = file.file.GetDirectory(path).Get(name)
+        try:
+            roothist = file.file.GetDirectory(path).Get(name)
+        except ReferenceError:
+            roothist = None
         if not roothist:
             hists.append(None)
             continue
@@ -375,6 +379,8 @@ def process_hist(path, name, counter, options):
                 ylabel = options.file_normalized_title % file_name
             else:
                 ylabel = options.scale_normalized_title % options.normalize
+        if options.area_normalize:
+            ylabel = options.area_normalized_title
         if dimension == 1:
             hist = r2m.Hist(roothist, replace=options.replace, label=file.name,
                             title=title, xlabel=xlabel, ylabel=ylabel)
@@ -386,6 +392,8 @@ def process_hist(path, name, counter, options):
             denom = r2m.Hist(file.file.Get(options.efficiency_from))
             hist.y, up, down = wilson(hist.y, denom.y)
             hist.yerr = [down, up]
+        hists.append(hist)
+    for hist in hists:
         if dimension == 1:
             if options.overflow:
                 hist.y[-1] += hist.overflow
@@ -410,7 +418,6 @@ def process_hist(path, name, counter, options):
                         hist.scale(numer / denom)
                 else:
                     hist.scale(options.normalize)
-        hists.append(hist)
     if options.mpl:
         process_hist_mpl(path, name, counter, options, hists)
     else:
@@ -428,35 +435,12 @@ def process_hist_root(path, name, counter, options, hists,
         pads[0].cd()
     else:
         pads = [canvas]
+    if options.xerr:
+        ROOT.gStyle.SetErrorX()
     histmax, first_draw, roothists = None, True, []
     multigraph = ROOT.TMultiGraph()
-    stack = ROOT.THStack('fullst%.3i' % counter,
+    stack = ROOT.THStack('st%.3i' % counter,
                          '%s;%s;%s' % (title, xlabel, ylabel))
-    for i, hist in enumerate(hists):
-        if hist:
-            if (type(hist) is r2m.Hist and not isTGraph and 
-                'stack' in options.drawcommands_root[i]):
-                stack.Add(hist.TH1F())
-            if stack.GetHists():
-                histmax = max(histmax, max(hist), stack.GetMaximum())
-            else:
-                histmax = max(histmax, max(hist))
-    dimension = 1
-    if type(hist) == r2m.Hist2D:
-        dimension = 2
-    if options.efficiency:
-        histmax = 1. / options.top_padding_factor
-    if options.gridx or options.grid:
-        for pad in pads:
-            pad.SetGridx(not pad.GetGridx())
-    if options.gridy or options.grid:
-        pads[0].SetGridy(not pads[0].GetGridy())
-    legend = ROOT.TLegend(*parse_legend_root(options))
-    for com in options.drawcommands_root:
-        if 'stack' in com:
-            first_draw = prep_first_draw(stack, histmax, options)
-            stack.Draw(options.draw)
-            break
     for i, hist in enumerate(hists):
         if not hist: continue
         if isTGraph:
@@ -473,6 +457,31 @@ def process_hist_root(path, name, counter, options, hists,
         roothist.SetMarkerStyle(options.markers_root[i])
         roothist.SetMarkerSize(options.markersizes[i])
         roothists.append(roothist)
+        if (type(hist) is r2m.Hist and not isTGraph and 
+            'stack' in options.drawcommands_root[i]):
+            stack.Add(roothist)
+        if stack.GetHists():
+            histmax = max(histmax, max(hist), stack.GetMaximum())
+        else:
+            histmax = max(histmax, max(hist))
+    dimension = 1
+    if type(hist) == r2m.Hist2D:
+        dimension = 2
+    if options.efficiency:
+        histmax = 1. / options.top_padding_factor
+    if options.gridx or options.grid:
+        for pad in pads:
+            pad.SetGridx(not pad.GetGridx())
+    if options.gridy or options.grid:
+        pads[0].SetGridy(not pads[0].GetGridy())
+    legend = ROOT.TLegend(*parse_legend_root(options))
+    for com in options.drawcommands_root:
+        if 'stack' in com:
+            first_draw = prep_first_draw(stack, histmax, options)
+            com = com.replace('stack', '')
+            stack.Draw(com)
+            break
+    for i, roothist in enumerate(roothists):
         if isTGraph:
             multigraph.Add(roothist)
         elif dimension == 1:
@@ -484,12 +493,15 @@ def process_hist_root(path, name, counter, options, hists,
                     roothist.Draw("same " + options.drawcommands_root[i])
         else:
             roothist.Draw(options.draw2D)
-        legend.AddEntry(roothist, options.filenames[i])
+        try:
+            legend.AddEntry(roothist, options.filenames[i][:-5])
+        except TypeError:
+            legend.AddEntry(roothist, options.filenames[i][1])
     if isTGraph:
         multigraph.Draw(options.draw_graph)
     if options.ratio and dimension == 1 and not isTGraph:
         pads[1].cd()
-        stack_ratio = plot_ratio_root(roothists, options)
+        stack_ratio = plot_ratio_root(hists, xlabel, options)
         pads[0].cd()
     if options.logx:
         for pad in pads:
@@ -517,7 +529,8 @@ def process_hist_root(path, name, counter, options, hists,
         a_label.SetFillStyle(0)
         a_label.Draw()
     save_plot(options.plot_dir, path, name, options.ext, counter)
-
+    del canvas
+    
 
 def process_hist_mpl(path, name, counter, options, hists):
     """Overlay all the instances of this plot and output using matplotlib."""
@@ -553,7 +566,10 @@ def process_hist_mpl(path, name, counter, options, hists):
                         # Logy would fail if hist all zeroes
                         if np.nonzero(hist.y)[0].tolist():
                             plt.yscale('log')
-                    hist.errorbar(yerr=True, fmt=options.markers_mpl[i],
+                    hist.errorbar(fmt=options.markers_mpl[i],
+                                  yerr=True,
+                                  xerr=options.xerr,
+                                  markersize=options.markersizes[i],
                                   color=options.fillcolors[i],
                                   ecolor=options.errorbarcolors_mpl[i],
                                   label_rotation=options.xlabel_rotation,
@@ -586,14 +602,14 @@ def process_hist_mpl(path, name, counter, options, hists):
             while (rounded_min > my_min):
                 rounded_min /= 10
             plt.ylim(ymin=rounded_min)
-        if options.zero and not options.logy:
-            plt.ylim(ymin=0.)
+        if options.xmin is not None:
+            plt.xlim(xmin=options.xmin)
+        if options.xmax is not None:
+            plt.xlim(xmax=options.xmax)
         if options.ymin is not None:
             plt.ylim(ymin=options.ymin)
-        if options.ymax:
+        if options.ymax is not None:
             plt.ylim(ymax=options.ymax)
-        if options.efficiency:
-            plt.ylim(ymax=1.)
         elif histmax != 0 and not options.ymax:
             plt.ylim(ymax=histmax * options.top_padding_factor)
         if options.overflow:
@@ -636,8 +652,13 @@ def process_hist_mpl(path, name, counter, options, hists):
                     counter, size=options.numbering_size_mpl,
                     ha=options.numbering_ha_mpl, va=options.numbering_va_mpl)
     output_file_name = '%s/%s/%s' % (options.plot_dir, path, name)
-    plt.savefig(output_file_name, transparent=options.transparent,
-                dpi=options.dpi)
+    try:
+        plt.savefig(output_file_name, transparent=options.transparent,
+                    dpi=options.dpi)
+    except RuntimeError:
+        plt.legend(numpoints=1, loc=1)
+        plt.savefig(output_file_name, transparent=options.transparent,
+                    dpi=options.dpi)
 
 
 ######## Define some supporting functions #####################################
@@ -769,11 +790,17 @@ def display_bin_text(x, y, nbins, text):
 def prep_first_draw(hist, histmax, options):
     """Set all the pad attributes that depend on the first object drawn."""
     hist.SetMaximum(histmax * options.top_padding_factor)
-    if options.zero and not ROOT.gPad.GetLogy():
-        hist.SetMinimum(0.)
+    if options.xmin is not None and options.xmax is not None:
+        hist.GetXaxis().SetRangeUser(options.xmin, options.xmax)
+    elif options.xmin is not None:
+        original_max = hist.GetBinLowEdge(hist.GetNbinsX() + 1)
+        hist.GetXaxis().SetRangeUser(options.xmin, original_max)
+    elif options.xmax is not None:
+        original_min = hist.GetBinLowEdge(1)
+        hist.GetXaxis().SetRangeUser(original_min, options.xmax)
     if options.ymin is not None:
         hist.SetMinimum(options.ymin)
-    if options.ymax:
+    if options.ymax is not None:
         hist.SetMaximum(options.ymax)
     if options.ratio:
         hist.GetXaxis().SetBinLabel(1, '') # Don't show numbers below top plot
@@ -803,27 +830,36 @@ def divide_canvas(canvas, ratio_fraction):
     pad_ratio.SetTopMargin(margins[0] + (1 - ratio_fraction) * useable_height)
     return pad, pad_ratio
 
-def plot_ratio_root(hists, options):
+def plot_ratio_root(hists, xlabel, options):
     """Plot the ratio of each hist in hists to the ratio_indexth hist."""
     ratio_index = options.ratio - 1
-    stack_ratio = ROOT.THStack('stRatio', ';%s;Ratio'
-                               % hists[1].GetXaxis().GetTitle())
-    for hist in (hists[0:ratio_index] + hists[ratio_index + 1:]):
-        ratio_hist = hist.Clone()
-        ratio_hist.Sumw2()
-        ratio_hist.Divide(hists[ratio_index])
-        average = ratio_hist.Integral() / ratio_hist.GetNbinsX()
-        for j in range(ratio_hist.GetNbinsX()):
-            if ratio_hist.GetBinContent(j) > options.ratio_cutoff * average:
-                ratio_hist.SetBinContent(j, 0)
-                ratio_hist.SetBinError(j, 0)
-        stack_ratio.Add(ratio_hist)
-    stack_ratio.Draw()
-    stack_ratio.GetYaxis().SetNdivisions(507) # Avoids crowded labels
-    if options.ratio_max: stack_ratio.SetMaximum(options.ratio_max)
-    if options.ratio_min is not None: stack_ratio.SetMinimum(options.ratio_min)
-    stack_ratio.Draw("nostack e")
-    return stack_ratio
+    multigraph = ROOT.TMultiGraph("ratio_mutli",
+                                  ";%s;%s" % (xlabel, options.ratio_label))
+    denom = hists[ratio_index]
+    for i, hist in enumerate(hists):
+        if i == ratio_index:
+            continue
+        if options.ratio_eff:
+            ratio_hist = hist.divide_wilson(denom)
+        else:
+            ratio_hist = hist.divide(denom)
+        ## average = ratio_hist.Integral() / ratio_hist.GetNbinsX()
+        ## for j in range(ratio_hist.GetNbinsX()):
+        ##     if ratio_hist.GetBinContent(j) > options.ratio_cutoff * average:
+        ##         ratio_hist.SetBinContent(j, 0)
+        ##         ratio_hist.SetBinError(j, 0)
+        graph = ratio_hist.TGraph()
+        graph.SetLineColor(options.linecolors[i])
+        graph.SetMarkerColor(options.markercolors[i])
+        graph.SetMarkerStyle(options.markers_root[i])
+        graph.SetMarkerSize(options.markersizes[i])
+        multigraph.Add(graph)
+    multigraph.Draw("ap")
+    multigraph.GetYaxis().SetNdivisions(507) # Avoids crowded labels
+    if options.ratio_max is not None: multigraph.SetMaximum(options.ratio_max)
+    if options.ratio_min is not None: multigraph.SetMinimum(options.ratio_min)
+    multigraph.Draw("ap")
+    return multigraph
 
 def divide_axes(axes, ratio_fraction):
     """Create two subaxes, the lower one taking up ratio_fraction of total."""
@@ -847,7 +883,10 @@ def plot_ratio_mpl(hists, options):
     stack = r2m.HistStack()
     for i in range(len(hists)):
         if i != ratio_index:
-            ratio_hist = hists[i] / hists[ratio_index]
+            if options.ratio_eff:
+                ratio_hist = hists[i].divide_wilson(hists[ratio_index])
+            else:
+                ratio_hist = hists[i] / hists[ratio_index]
             ratio_hist.y = [item or 0 for item in ratio_hist.y]
             average = sum(ratio_hist.y) / ratio_hist.nbins
             for j in range(ratio_hist.nbins):
@@ -865,6 +904,9 @@ def plot_ratio_mpl(hists, options):
     if options.ratio_max: plt.ylim(ymax=options.ratio_max)
     if options.ratio_min is not None: plt.ylim(ymin=options.ratio_min)
     plt.ylabel('Ratio')
+    plt.gca().yaxis.tick_right()
+    plt.gca().yaxis.set_label_position('right')
+    plt.gca().yaxis.label.set_rotation(-90)
 
 def wilson(numerator, denominator):
     nbins = len(numerator)
@@ -997,11 +1039,13 @@ def process_options(options):
     """Select plot-level options based on the user-level input."""
     options.nfiles = nfiles = len(options.filenames)
     if nfiles > 1: options.draw2D = None
+    if options.ratio_eff: options.ratio = options.ratio_eff
+    if options.ratio_eff: options.ratio_max = 1.
     if options.merge: options.ext = 'pdf'
-    if options.stack: options.mpl = 'stack'
-    elif options.bar: options.mpl = 'bar'
+    if options.bar: options.mpl = 'bar'
     elif options.errorbar: options.mpl = 'errorbar'
     elif options.hist: options.mpl = 'hist'
+    if options.mpl and options.stack: options.mpl = 'stack'
     if options.mpl and type(options.mpl) is not str:
         options.mpl = 'hist'
     try:
@@ -1069,9 +1113,15 @@ def process_options(options):
     if not options.plotstyles_mpl:
         options.plotstyles_mpl = [options.mpl for i in xrange(nfiles)]
     if not options.drawcommands_root:
-        options.drawcommands_root = [options.draw for i in xrange(nfiles)]
+        if options.stack:
+            options.drawcommands_root = ['stack ' + options.draw
+                                         for i in xrange(nfiles)]
+        else:
+            options.drawcommands_root = [options.draw for i in xrange(nfiles)]
     if not options.markersizes:
-        if options.markers: size = ROOT.gStyle.GetMarkerSize()
+        if options.markers:
+            if options.mpl: size = matplotlib.rcParams['lines.markersize']
+            else: size = ROOT.gStyle.GetMarkerSize()
         else: size = 0
         options.markersizes = [size for i in xrange(nfiles)]
     if not options.errorbarcolors_mpl:
@@ -1102,41 +1152,31 @@ def process_options(options):
                                for x in colors])
     return options
 
-def get_plot_specific_options(histname, dict_options):
-    matching_options = []
-    for key in dict_options.keys():
-        for string in dict_options[key]:
-            if string and string in histname:
-                matching_options.append(key)
-                break
-    return matching_options
-
 def process_local_options(options, name):
     """Turn on sticky options for a particular plot."""
     new_options = copy.copy(options)
-    if options.sticky:
-        if 'Norm' in name: new_options.area_normalize = True
-        if 'Eff' in name: new_options.efficiency = True
-        if 'Logx' in name: new_options.logx = True
-        if 'Logy' in name: new_options.logy = True
-        if 'Zero' in name: new_options.zero = True
-	if 'Overflow' in name: new_options.overflow = True
-        if 'Underflow' in name: new_options.underflow = True
-        if 'Ratio' in name: new_options.ratio = True
-    specific_options = get_plot_specific_options(name,
-                                                 options.options_by_histname)
-    if specific_options:
-        if 'norm' in specific_options: new_options.area_normalize = True
-        if 'efficiency' in specific_options: new_options.efficiency = True
-        if 'logx' in specific_options: new_options.logx = True
-        if 'logy' in specific_options: new_options.logy = True
-        if 'zero' in specific_options: new_options.zero = True
-        if 'overflow' in specific_options: new_options.overflow = True
-        if 'underflow' in specific_options: new_options.underflow = True
-        if 'ratio' in specific_options: new_options.ratio = True
+    def apply_opt(opt):
+        if options.sticky and opt in name:
+            return True
+        for string in new_options.options_by_histname[opt]:
+            if string and string in name:
+                return True
+        return False
+    if apply_opt('Norm'): new_options.area_normalize = True
+    if apply_opt('Eff'): new_options.efficiency = True
+    if apply_opt('Logx'): new_options.logx = True
+    if apply_opt('Logy'): new_options.logy = True
+    if apply_opt('Zero'): new_options.zero = True
+    if apply_opt('Overflow'): new_options.overflow = True
+    if apply_opt('Underflow'): new_options.underflow = True
+    if apply_opt('Ratio'): new_options.ratio = True
+    if new_options.zero:
+        new_options.ymin = 0
     if new_options.logy:
-        new_options.zero = False
+        new_options.ymin = None
         new_options.top_padding_factor = options.top_padding_factor_log
+    if new_options.efficiency:
+        new_options.ymax = 1.
     return new_options
 
 
@@ -1173,7 +1213,8 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
   system, you can produce output in matplotlib.  This will be activated by
   enabling any of the options 'mpl', 'bar', 'errorbar', 'hist', or 'stack'.""")
 
-    parser = optparse.OptionParser(usage=usage,
+    help_formatter = optparse.IndentedHelpFormatter(width=ncolumns)
+    parser = optparse.OptionParser(usage=usage, formatter=help_formatter,
                                    version='%s %s' % ('%prog', __version__))
     parser.add_option('--config', action='store_true',
                       help="do nothing but write a template configuration file "
@@ -1190,6 +1231,8 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
     parser.add_option('--noclean', action='store_true', default=False,
                       help="skips destroying the output directory before "
                       "drawing")
+    parser.add_option('--stack', action="store_true", default=False,
+                      help="stack histograms")
     parser.add_option('--data', type='int', default=0, metavar='FILENUM',
                       help="the histogram from the FILENUMth (starting from 1) "
                       "file will be drawn as black datapoints, while all "
@@ -1204,6 +1247,10 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
                       help="only process plot(s) in the given location or its "
                       "subdirectories; PATH may be a regular expression (use "
                       ".* for wildcard)")
+    parser.add_option('--xmax', type='float', default=None,
+                      help="set the maximum value of the x-axis")
+    parser.add_option('--xmin', type='float', default=None,
+                      help="set the minimum value of the x-axis")
     parser.add_option('--ymax', type='float', default=None,
                       help="set the maximum value of the y-axis")
     parser.add_option('--ymin', type='float', default=None,
@@ -1274,6 +1321,10 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
                       help="'Ratio': cut the canvas in two, displaying on the "
                       "bottom the ratio of each histogram to the histogram in "
                       "the FILENUMth (starting from 1) file.")
+    group1.add_option('--ratio-eff', type='int', default=0, metavar='FILENUM',
+                      help="'Ratio': cut the canvas in two, displaying on the "
+                      "bottom the ratio of each histogram to the histogram in "
+                      "the FILENUMth (starting from 1) file.")
     group2 = optparse.OptionGroup(parser,"Options specific to ROOT (default)"
                                   " output")
     group2.add_option('--draw', default='p H', metavar='"p H"',
@@ -1289,19 +1340,19 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
                                 "Producing output with matplotlib")
     group3.add_option('--mpl', action="store_true", default=False,
                       help="produce output in matplotlib; automatically "
-                      "turned on by --stack, --errorbar, --bar, or --hist")
+                      "turned on by --errorbar, --bar, or --hist")
     group3.add_option('--mpl2D', default='box', metavar='"box"',
                       help="Type of plot to produce for 2D histograms in "
                       "matplotlib.  Choose from 'contour', 'col', 'colz', or "
                       "'box'")
-    group3.add_option('--stack', action="store_true", default=False,
-                      help="output a matplotlib stacked bar graph")
     group3.add_option('--errorbar', action="store_true", default=False,
                       help="output a matplotlib errorbar graph")
     group3.add_option('--bar', action="store_true", default=False,
                       help="output a matplotlib bar graph")
     group3.add_option('--hist', action="store_true", default=False,
                       help="output a matplotlib hist graph (with solid fill)")
+    group3.add_option('--xerr', action="store_true", default=False,
+                      help="show width of bins in errorbar output")
     group3.add_option('--alpha', type='float', default=0.5,
                       help="set the transparency factor used for matplotlib "
                       "bar and hist graphs "
@@ -1321,14 +1372,13 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
     options.plot_dir = '%s/%s' % (os.path.abspath('.'), options.output)
     options.regex = re.compile(options.path)
     for arg in arguments:
-        if arg[-5:] != ".root" and arg[-3:] != ".py":
+        if not arg.endswith(".root") and not arg.endswith(".py"):
             raise TypeError("Arguments must be root files "
                             "or python configurations!")
-    options.config_files = [x for x in arguments if x[-3:] == ".py"]
-    filenames_from_interface = [x for x in arguments if x[-5:] == ".root"]
+    options.config_files = [x for x in arguments if x.endswith(".py")]
+    filenames_from_interface = [x for x in arguments if x.endswith(".root")]
     ## add style options and create the canvas
     options = add_options_from_configuration(options)
-    options.top_padding_factor_cfg = options.top_padding_factor # store cfg default
     if "filenames" in dir(options):
         if filenames_from_interface:
             print "Warning: filenames parameter defined in configuration;"
